==> server-core-3.0.3-sources.jar: com/xebialabs/deployit/security/permission/UpgradeDeploymentHandler.java <==
package com.xebialabs.deployit.security.permission;

import com.xebialabs.deployit.ConfigurationItemRoot;
import com.xebialabs.deployit.jcr.JcrConstants;
import com.xebialabs.deployit.repository.JcrRepositoryServiceHolder;
import com.xebialabs.deployit.repository.RepositoryObjectEntity;

import java.util.Collection;

import static com.xebialabs.deployit.checks.Checks.checkArgument;

public class UpgradeDeploymentHandler extends PermissionHandler {

	@Override
	protected void handle(String user, Action action) {
		permission(Permission.DEPLOY_UPGRADE, user, action);
		privileges(ADD_CHILD_NODES_PRIVILEGES, user, "Environments", action);
		privileges(ADD_CHILD_NODES_PRIVILEGES, user, "Infrastructure", action);
		privileges(REMOVE_CHILD_NODES_PRIVILEGES, user, "Infrastructure", action);
		privileges(ADD_CHILD_NODES_PRIVILEGES, user, JcrConstants.TASKS_NODE_NAME, action);
	}

	@Override
	protected void handle(String user, String onConfigurationItem, Action action) {
		checkArgument(onConfigurationItem.startsWith(ConfigurationItemRoot.ENVIRONMENTS.getRootNodeName()), "%s is not an Environment", onConfigurationItem);
		permission(Permission.DEPLOY_UPGRADE, user, onConfigurationItem, action);
		privileges(ADD_CHILD_NODES_PRIVILEGES, user, onConfigurationItem, action);
		final RepositoryObjectEntity objectEntity = JcrRepositoryServiceHolder.getRepositoryService().read(onConfigurationItem);
		privileges(ADD_CHILD_NODES_PRIVILEGES, user, (Collection<String>) objectEntity.getValue("members"), action);
		privileges(REMOVE_CHILD_NODES_PRIVILEGES, user, (Collection<String>) objectEntity.getValue("members"), action);
		privileges(ADD_CHILD_NODES_PRIVILEGES, user, JcrConstants.TASKS_NODE_NAME, action);
	}

	@Override
	Permission getPermission() {
		return Permission.DEPLOY_UPGRADE;
	}
}

==> server-core-3.5.1-sources.jar: com/xebialabs/deployit/security/permission/UpgradeDeploymentHandler.java <==
package com.xebialabs.deployit.security.permission;

import static com.xebialabs.deployit.checks.Checks.checkArgument;

import java.util.Collection;

import com.xebialabs.deployit.jcr.JcrConstants;
import com.xebialabs.deployit.plugin.api.udm.Metadata;
import com.xebialabs.deployit.repository.JcrRepositoryServiceHolder;
import com.xebialabs.deployit.repository.RepositoryObjectEntity;

public class UpgradeDeploymentHandler extends PermissionHandler {

	@Override
	protected void handle(String user, Action action) {
		permission(Permission.DEPLOY_UPGRADE, user, action);
		privileges(ADD_CHILD_NODES_PRIVILEGES, user, "Environments", action);
		privileges(ADD_CHILD_NODES_PRIVILEGES, user, "Infrastructure", action);
		privileges(REMOVE_CHILD_NODES_PRIVILEGES, user, "Infrastructure", action);
		privileges(ADD_CHILD_NODES_PRIVILEGES, user, JcrConstants.TASKS_NODE_NAME, action);
	}

	@Override
	protected void handle(String user, String onConfigurationItem, Action action) {
		checkArgument(onConfigurationItem.startsWith(Metadata.ConfigurationItemRoot.ENVIRONMENTS.getRootNodeName()), "%s is not an Environment", onConfigurationItem);
		permission(Permission.DEPLOY_UPGRADE, user, onConfigurationItem, action);
		privileges(ADD_CHILD_NODES_PRIVILEGES, user, onConfigurationItem, action);
		final RepositoryObjectEntity objectEntity = JcrRepositoryServiceHolder.getRepositoryService().read(onConfigurationItem);
		privileges(ADD_CHILD_NODES_PRIVILEGES, user, (Collection<String>) objectEntity.getValue("members"), action);
		privileges(REMOVE_CHILD_NODES_PRIVILEGES, user, (Collection<String>) objectEntity.getValue("members"), action);
		privileges(ADD_CHILD_NODES_PRIVILEGES, user, JcrConstants.TASKS_NODE_NAME, action);
	}

	@Override
	Permission getPermission() {
		return Permission.DEPLOY_UPGRADE;
	}
}
